local flash = {}
local rayPieces = 15

local function rayGenerator(nPieces)
  math.randomseed(os.time())
  
  -- First "piece"
  flash.currRay[0] = {
    x1 = -1,
    y1 = -1,
    x2 = math.random(0.35*winWidth, 0.65*winWidth),
    y2 = 0,
  }
  
  -- Each piece depends on the last one (position "i-1")
  for i=1, nPieces do
    local lastPointX = flash.currRay[i-1].x2
    local lastPointY = flash.currRay[i-1].y2
    local randAngle = math.random(0.1, math.pi/3)
    local randSize = math.random(20, 60)
    local randDir = math.random(-1, 1)
    local newX = lastPointX + randDir*math.tan(randAngle)*randSize
    
    table.insert(flash.currRay, {
      x1 = lastPointX,
      y1 = lastPointY,
      x2 = newX,
      y2 = lastPointY + randSize,
    })
  end
end

function flash.load()
  flash.currFrame = 1
  flash.timer = 0
  flash.animTimer = 0
  flash.opacity = 0.7
  flash.currRay = {}
  flash.maxThunderTimer = 6
  rayGenerator(rayPieces)
end

function flash.update(dt)
  flash.animTimer = flash.animTimer + dt
  if flash.animTimer > flash.maxThunderTimer then
    flash.timer = flash.timer + dt
    if flash.timer > 0.1 then
      if flash.currFrame <= 7 then
        flash.currFrame = flash.currFrame + 1
        if flash.currFrame >= 4 then
          flash.opacity = flash.opacity - 0.1
        end
      else
        flash.currFrame = 1
        flash.animTimer = 0
        flash.opacity = 0.7
        flash.currRay = {}
        flash.maxThunderTimer = math.random(5, 20)
        rayGenerator(rayPieces)
      end
      flash.timer = 0
    end
  end
  
  if flash.currFrame == 5 then
    love.audio.play(thunderAudio)
  end
end

function flash.draw()
  local gr = love.graphics
  if flash.currFrame % 2 > 0 and flash.currFrame <= 4 then
    gr.setColor(0,0,0, 0.7)
    gr.rectangle("fill", 0, 0, winWidth, winHeight)
  elseif flash.currFrame == 2 then
    gr.setColor(1,1,1)
    gr.rectangle("fill", 0, 0, winWidth, winHeight)
  else
    gr.setColor(1,1,1, flash.opacity)
    gr.rectangle("fill", 0, 0, winWidth, winHeight)
  end
  
  local ray = flash.currRay
  for i=1, #ray do
    local currR = ray[i]
    gr.line(currR.x1, currR.y1, currR.x2, currR.y2)
  end
end

return flash