local rain = require "rain"
local house = {}

local function rainDropsCollision(drop, obj)
  return drop.y < obj.y + obj.height and
         drop.x < obj.x + obj.width and
         obj.y < drop.y + 1 and
         obj.x < drop.x + 1
end

function house.load()
  house.roof = {
    x = 50,
    y = 150,
    size = 10,
    layers = 4,
    color = {1, 0, 1},
    tiles = {},
  }
  house.borders = {
    x = 50,
    y = 190,
    height = 410,
  }
  house.floor = {
    x = 50,
    y = 590,
    height = 10,
  }
  house.floodLvl = 0
  house.floodLimit = 150
  
  -- Building tiles array
  local roof = house.roof
  local nTiles = (winWidth - 2*roof.x)/roof.size
  local nLayers = roof.layers
  local size = roof.size
  house.width = nTiles*size
  house.height = 400
  house.floor.width = house.width
  
  for j=1, nLayers do
    for i=1, nTiles do
      table.insert(house.roof.tiles, {
        x = roof.x + (i-1)*size,
        y = roof.y + (j-1)*size,
        width = size,
        height = size,
        removed = false,
      })
    end
  end
end

function house.update(dt)
  local roof = house.roof
  local floor = house.floor
  local drops = rain.drops
  
  for j=#drops, 1, -1 do
    local currD = drops[j]
    
    for i=#roof.tiles, 1, -1 do
      local currT = roof.tiles[i]
      local damaged = rainDropsCollision(currD, currT)
      
      if (not currT.removed and damaged) then
        local rand = math.random(1, 10)
        
        if (rand == 1) then
          currT.removed = true
        end
        table.remove(drops, j)
      end
    end
    
    if (rainDropsCollision(currD, floor)) then
      house.floodLvl = house.floodLvl < house.floodLimit and house.floodLvl + 1/5 or house.floodLvl
      table.remove(drops, j)
    end
  end
end

function house.draw()
  local gr = love.graphics
  local roof = house.roof
  local floor = house.floor
  local borders = house.borders
  local size = roof.size
  
  -- Drawing the house borders
  gr.setColor(1,1,1)
  gr.rectangle("line", borders.x, borders.y, house.width, borders.height)
  
  -- Gambiarration
  gr.setColor(0,0,0)
  gr.rectangle("fill", borders.x + 1, borders.y - 10, house.width - 2, 20)
  
  -- Drawing the house roof
  gr.setColor(roof.color)
  for i=1, #roof.tiles do
    local curr = roof.tiles[i]
    if not curr.removed then
      gr.rectangle("fill", curr.x, curr.y, curr.width, curr.height)
    end
  end
  
  -- Drawing the house floor collider
  --gr.setColor(0,1,0)
  --gr.rectangle("line", floor.x, floor.y, floor.width, floor.height)
  
  -- Drawing flooded water
  local currFloodY = (winHeight - house.floodLvl)
  love.graphics.setColor(28/255,163/255,236/255)
  gr.rectangle("fill", floor.x, currFloodY, floor.width, house.floodLvl)
end

return house