local house = require "house"
local player = {}

local function bricksCollision(brick, tile)
  local size = 5
  return brick.y < tile.y + tile.height and
         brick.x < tile.x + tile.width and
         tile.y < brick.y + brick.size and
         tile.x < brick.x + brick.size
end

function player.load()
  player.x = winWidth/2
  player.y = winHeight - house.floodLimit/2
  player.vel = 250
  player.fatness = 15
  player.bricks = {}
  player.bricks.size = 15
  player.bricks.vel = 300
  player.cooldown = 0.5
  player.timer = 0
  player.score = 0
end

function player.update(dt)
  local kb = love.keyboard
  local bricks = player.bricks
  
  -- Player Movement
  if kb.isDown("w") then
    player.y  = player.y - player.vel*dt
  elseif kb.isDown("s") then
    player.y  = player.y + player.vel*dt
  elseif kb.isDown("a") then
    player.x  = player.x - player.vel*dt
  elseif kb.isDown("d") then
    player.x  = player.x + player.vel*dt
  end
  
  -- Player "Shooting" (Bricks) System
  player.timer = player.timer + dt
  if kb.isDown("space") then
    if player.timer > player.cooldown then
      table.insert(bricks, {
        x = player.x - bricks.size/2,
        y = player.y - bricks.size/2,
        size = bricks.size,
      })
      player.timer = 0
    end
  end
  
  -- Flying Bricks' UPDATE
  for i=#bricks, 1, -1 do
    local currBr = bricks[i]
    -- Moving the flying bricks
    currBr.y = currBr.y - bricks.vel*dt
    
    -- Verifying collision with house's roof
    local tiles = house.roof.tiles
    for j=1, #tiles do
      local currT = tiles[j]
      if (currT.removed and bricksCollision(currBr, currT)) then
        table.remove(bricks, i)
        currT.removed = false
        player.score = player.score + 5
        love.audio.play(brickAudio)
      end
    end
  end
  
  local roof = house.roof
  if player.x < roof.x + player.fatness then
    player.x = roof.x + player.fatness
  elseif player.x > roof.x + house.width - player.fatness then
    player.x = roof.x + house.width - player.fatness
  end
  
  if house.floodLvl > 50 then
    player.cooldown = 0.1
  end
  
  if player.y < winHeight - house.floodLimit + player.fatness then
    player.y = winHeight - house.floodLimit + player.fatness
  elseif player.y > winHeight - player.fatness then
    player.y = winHeight - player.fatness
  end
end

function player.draw()
  local gr = love.graphics
  local bricks = player.bricks
  
  -- Drawing the player
  gr.setColor(1,1,1)
  gr.circle("fill", player.x, player.y, player.fatness)
  
  -- Drawing the flying bricks
  gr.setColor(1, 0, 1)
  for i=1, #bricks do
    local currBr = bricks[i]
    gr.rectangle("fill", currBr.x, currBr.y, bricks.size, bricks.size)
  end
  
  -- Drawing score on screen
  gr.setColor(1,1,1)
  gr.printf(string.format("Score: %06d", player.score), 0, 10, winWidth, "center")
end

return player